@@ -23,6 +23,10 @@
 #endif
 #endif
 
+#if !defined(_WIN32)
+#define __cdecl
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -156,7 +160,7 @@ typedef struct cli_cstring_t {
 } cli_cstring_t;
 
 
-#if defined(_WIN32)
+#if defined(_WIN32) && !defined(__MINGW32__)
 typedef __int64      cli_int8_t;
 #else
 #if SIZEOF_LONG == 8
