@@ -166,13 +166,7 @@ class GIGABASE_DLL_ENTRY dbAnyCursor : public dbL2List {
     // If "arr" is null, then new array is created by  new oid_t[] and returned by this
     // method
     //
-    oid_t* toArrayOfOid(oid_t* arr) { 
-	if (arr == NULL) { 
-	    arr = new oid_t[selection.nRows];
-	}
-	selection.toArray(arr);
-	return arr;
-    }
+    oid_t* toArrayOfOid(oid_t* arr);
 
     int select(dbQuery& query, void* paramStruct = NULL) {
 	return select(query, defaultType, paramStruct);
@@ -236,6 +230,8 @@ class GIGABASE_DLL_ENTRY dbAnyCursor : public dbL2List {
 
     bool skip(int n);
 
+    dbTableDescriptor* getTable() { return table; }
+
   protected:
     dbDatabase*        db;
     dbTableDescriptor* table;
@@ -337,6 +333,9 @@ class GIGABASE_DLL_ENTRY dbAnyCursor : public dbL2List {
 	eliminateDuplicates = false;
 	db = aTable.db;
 	paramBase = NULL;
+	stmtLimitLen = dbDefaultSelectionLimit;
+	stmtLimitStart = 0;
+	nSkipped = 0;
     }
     ~dbAnyCursor();
 };
@@ -399,6 +398,11 @@ class dbCursor : public dbAnyCursor {
 	return dbReference<T>(currId);
     }
 
+    void toArray(dbArray< dbReference<T> >& arr) { 
+	arr.resize(selection.nRows);
+	toArrayOfOids((oid_t*)arr.base());
+    }
+
     //
     // Method nextAvailable allows to iterate through the records in uniform way even when some records 
     // are removed. For example:
