@@ -51,10 +51,13 @@ const size_t dbBitmapSegmentSize = 1 << dbBitmapSegmentBits;
 const size_t dbBitmapPages = 1 << (dbDatabaseOffsetBits-dbBitmapSegmentBits);
 const size_t dbDirtyPageBitmapSize = 1 << (dbDatabaseOidBits-dbPageBits-3);
 const size_t dbDefaultSelectionLimit = 2000000000;
-
+//
+// IN operator for all strings with length grater or equal than dbBMsearchThreshold will
+// be performed using BM substring search algorithm
+//
 const int    dbBMsearchThreshold = 512;
 
-const char_t dbMatchAnyOneChar = '_';
+const char_t dbMatchAnyOneChar = '_'; 
 const char_t dbMatchAnySubstring = '%';
 
 const int    dbMaxFileSegments = 64;
@@ -258,7 +261,7 @@ class GIGABASE_DLL_ENTRY dbDatabase {
 
     virtual ~dbDatabase();
 
-    static void cleanup();
+    static void __cdecl cleanup();
     
   protected:
     dbThreadContext<dbDatabaseThreadContext> threadContext;
