@@ -476,7 +476,7 @@ inline dbQuery& add(dbQuery& query, dbArray< dbReference<T> >const* const& value
 }
 #endif
 
-#define USER_FUNC(f) static dbUserFunction f##_descriptor(&f, #f)
+#define USER_FUNC(f) static dbUserFunction f##_descriptor(&f, STRLITERAL(#f))
 
 class  dbInheritedAttribute;
 class  dbSynthesizedAttribute;
@@ -564,80 +564,80 @@ class GIGABASE_DLL_ENTRY dbUserFunction {
 
     int getNumberOfParameters();
 
-    dbUserFunction(bool __cdecl (*f)(int8), char_t* name) {
+    dbUserFunction(bool (__cdecl *f)(int8), char_t* name) {
 	bind(name, (void*)f, fInt2Bool);
     }
-    dbUserFunction(bool __cdecl (*f)(real8), char_t* name) {
+    dbUserFunction(bool (__cdecl *f)(real8), char_t* name) {
 	bind(name, (void*)f, fReal2Bool);
     }
-    dbUserFunction(bool __cdecl (*f)(char_t const*), char_t* name) {
+    dbUserFunction(bool (__cdecl *f)(char_t const*), char_t* name) {
 	bind(name, (void*)f, fStr2Bool);
     }
-    dbUserFunction(int8 __cdecl (*f)(int8), char_t* name) {
+    dbUserFunction(int8 (__cdecl *f)(int8), char_t* name) {
 	bind(name, (void*)f, fInt2Int);
     }
-    dbUserFunction(int8 __cdecl (*f)(real8), char_t* name) {
+    dbUserFunction(int8 (__cdecl *f)(real8), char_t* name) {
 	bind(name, (void*)f, fReal2Int);
     }
-    dbUserFunction(int8 __cdecl (*f)(char_t const*), char_t* name) {
+    dbUserFunction(int8 (__cdecl *f)(char_t const*), char_t* name) {
 	bind(name, (void*)f, fStr2Int);
     }
-    dbUserFunction(real8 __cdecl (*f)(int8), char_t* name) {
+    dbUserFunction(real8 (__cdecl *f)(int8), char_t* name) {
 	bind(name, (void*)f, fInt2Real);
     }
-    dbUserFunction(real8 __cdecl (*f)(real8), char_t* name) {
+    dbUserFunction(real8 (__cdecl *f)(real8), char_t* name) {
 	bind(name, (void*)f, fReal2Real);
     }
-    dbUserFunction(real8 __cdecl (*f)(char_t const*), char_t* name) {
+    dbUserFunction(real8 (__cdecl *f)(char_t const*), char_t* name) {
 	bind(name, (void*)f, fStr2Real);
     }
-    dbUserFunction(char_t* __cdecl (*f)(int8), char_t* name) {
+    dbUserFunction(char_t* (__cdecl *f)(int8), char_t* name) {
 	bind(name, (void*)f, fInt2Str);
     }
-    dbUserFunction(char_t* __cdecl (*f)(real8), char_t* name) {
+    dbUserFunction(char_t* (__cdecl *f)(real8), char_t* name) {
 	bind(name, (void*)f, fReal2Str);
     }
-    dbUserFunction(char_t* __cdecl (*f)(char_t const*), char_t* name) {
+    dbUserFunction(char_t* (__cdecl *f)(char_t const*), char_t* name) {
 	bind(name, (void*)f, fStr2Str);
     }
 
-    dbUserFunction(bool __cdecl (*f)(dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(bool (__cdecl *f)(dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArg2Bool); 
     }
-    dbUserFunction(char_t* __cdecl (*f)(dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(char_t* (__cdecl *f)(dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArg2Str); 
     }
-    dbUserFunction(int8 __cdecl (*f)(dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(int8 (__cdecl *f)(dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArg2Int); 
     }
-    dbUserFunction(real8 __cdecl (*f)(dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(real8 (__cdecl *f)(dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArg2Real); 
     }
 
-    dbUserFunction(bool __cdecl (*f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(bool (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArgArg2Bool); 
     }
-    dbUserFunction(char_t* __cdecl (*f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(char_t* (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArgArg2Str); 
     }
-    dbUserFunction(int8 __cdecl (*f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(int8 (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArgArg2Int); 
     }
-    dbUserFunction(real8 __cdecl (*f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(real8 (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArgArg2Real); 
     }
 
 
-    dbUserFunction(bool __cdecl (*f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(bool (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArgArgArg2Bool); 
     }
-    dbUserFunction(char_t* __cdecl (*f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(char_t* (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArgArgArg2Str); 
     }
-    dbUserFunction(int8 __cdecl (*f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(int8 (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArgArgArg2Int); 
     }
-    dbUserFunction(real8 __cdecl (*f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
+    dbUserFunction(real8 (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
 	bind(name, (void*)f, fArgArgArg2Real); 
     }
 };
